'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _typeof2 = require('babel-runtime/helpers/typeof');

var _typeof3 = _interopRequireDefault(_typeof2);

exports.default = processModules;
exports.handleMiddlewares = handleMiddlewares;

var _reduxActions = require('redux-actions');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function processModules(modules) {
  var reducers = modules.filter(function (module) {
    return typeof module.reducer == 'function' || (0, _typeof3.default)(module.reducer) == 'object';
  }).map(function (module) {
    return typeof module.reducer == 'function' ? module.reducer : (0, _reduxActions.handleActions)(module.reducer);
  });

  var middlewares = modules.filter(function (module) {
    return typeof module.middleware == 'function' || (0, _typeof3.default)(module.middleware) == 'object';
  }).map(function (module) {
    return typeof module.middleware == 'function' ? module.middleware : handleMiddlewares(module.middleware);
  });

  var enhancers = modules.filter(function (module) {
    return typeof module.enhancer == 'function';
  }).map(function (module) {
    return module.enhancer;
  });

  return {
    reducers: reducers,
    middlewares: middlewares,
    enhancers: enhancers
  };
}

function handleMiddlewares(listeners) {
  return function (store) {
    return function (next) {
      return function (action) {
        // Execute action listeners, if any was set for the current action.
        if (listeners[action.type]) {
          return listeners[action.type](store)(next)(action);
        }

        return next(action);
      };
    };
  };
}